<!DOCTYPE html>
<html>
    <head>
        <meta charset="utf-8" />
        <link rel="stylesheet" href="https://cdn.jsdelivr.net/qunit/1.14.0/qunit.css" type="text/css" media="screen" />
    </head>
    <body>
        <div id="qunit"></div>
        <div id="qunit-fixture"></div>
        <script src="http://cdn.jsdelivr.net/qunit/1.14.0/qunit.js"></script>
        <script src="../emojione.js"></script>
        <script>
        <% _.each(data, function(collection) { %>
            QUnit.module("<%= collection.module %>");
            <% _.each(collection.tests, function(test) { %>
                QUnit.test( "<%= test.description %>", function( assert ) {
                    assert.equal(emojione.<%= collection.module %>("<%= test.text %>"), "<%= test.expected %>");
                });
            <% }); %>
        <% }); %>
        </script>
    </body>
</html>
