# -*- coding: utf-8; -*-

from setuptools import setup

setup(name='emojipy',
      version='0.1',
      description='Python wrapper for emojione',
      author='Kaviraj Kanagaraj',
      author_email='kaviraj@launchyard.com',
      packages=['emojipy',],
      test_suite='emojipy.tests',
)
